@@ -41,7 +41,7 @@ RenewalData::RenewalData(CommentStream& infile, const IntVector& Areas,
     //read renewal data in mean length format, using the reference weight file
     readoption = 0;
     infile >> text >> ws;
-    subfile.open(text, ios::in);
+    subfile.open(text, ios::binary);
     handle.checkIfFailure(subfile, text);
     handle.Open(text);
     this->readNormalConditionData(subcomment, keeper, TimeInfo, Area, minage, maxage);
@@ -52,7 +52,7 @@ RenewalData::RenewalData(CommentStream& infile, const IntVector& Areas,
     //read information on reference weights.
     DoubleMatrix tmpRefW;
     keeper->addString("referenceweights");
-    subfile.open(refWeightFile, ios::in);
+    subfile.open(refWeightFile, ios::binary);
     handle.checkIfFailure(subfile, refWeightFile);
     handle.Open(refWeightFile);
     readRefWeights(subcomment, tmpRefW);
@@ -87,7 +87,7 @@ RenewalData::RenewalData(CommentStream& infile, const IntVector& Areas,
     //read renewal data in mean length format, using a length weight relationship
     readoption = 1;
     infile >> text >> ws;
-    subfile.open(text, ios::in);
+    subfile.open(text, ios::binary);
     handle.checkIfFailure(subfile, text);
     handle.Open(text);
     this->readNormalParameterData(subcomment, keeper, TimeInfo, Area, minage, maxage);
@@ -99,7 +99,7 @@ RenewalData::RenewalData(CommentStream& infile, const IntVector& Areas,
     //read renewal data in number format
     readoption = 2;
     infile >> text >> ws;
-    subfile.open(text, ios::in);
+    subfile.open(text, ios::binary);
     handle.checkIfFailure(subfile, text);
     handle.Open(text);
     this->readNumberData(subcomment, keeper, TimeInfo, Area, minage, maxage);
@@ -383,7 +383,7 @@ void RenewalData::Print(ofstream& outfile) const {
     if (renewalTime[i] == renewalTime[index]) {
       outfile << "\tInternal area " << renewalArea[i] << " age " << renewalAge[i];
 
-      if (readoption == 2)
+      if (readoption == 2) //numberfile
         outfile << "\n\tNumbers\n";
       else
         outfile << " multiplier " << renewalMult[i] << "\n\tNumbers\n";
@@ -401,7 +401,7 @@ void RenewalData::Reset() {
   double sum, mult, dnorm;
 
   index = 0;
-  if (readoption == 0) {
+  if (readoption == 0) {  // normalcond
     for (i = 0; i < renewalTime.Size(); i++) {
       age = renewalAge[i];
 
@@ -446,7 +446,7 @@ void RenewalData::Reset() {
       }
     }
 
-  } else if (readoption == 1) {
+  } else if (readoption == 1) { // normalparam
     for (i = 0; i < renewalTime.Size(); i++) {
       age = renewalAge[i];
 
@@ -491,7 +491,7 @@ void RenewalData::Reset() {
       }
     }
 
-  } else if (readoption == 2) {
+  } else if (readoption == 2) { // numeric
     for (i = 0; i < renewalTime.Size(); i++) {
       age = renewalAge[i];
       minage = renewalDistribution[i].minAge();
