@@ -200,10 +200,10 @@ Stock::Stock(CommentStream& infile, const char* givenname,
     } else if (strcasecmp(text, "fixedlength") == 0) {
       maturity = new MaturityB(subcomment, TimeInfo, keeper, minage, numage, areas, this->getName(), LgrpDiv);
 
-    } else if ((strcasecmp(text, "newconstant") == 0) | (strcasecmp(text, "constant") == 0)) {
+    } else if ((strcasecmp(text, "newconstant") == 0) || (strcasecmp(text, "constant") == 0)) {
       maturity = new MaturityC(subcomment, TimeInfo, keeper, minage, numage, areas, this->getName(), LgrpDiv, 4);
 
-    } else if ((strcasecmp(text, "newconstantweight") == 0) | (strcasecmp(text, "constantweight") == 0)) {
+    } else if ((strcasecmp(text, "newconstantweight") == 0) || (strcasecmp(text, "constantweight") == 0)) {
       maturity = new MaturityD(subcomment, TimeInfo, keeper, minage, numage, areas, this->getName(), LgrpDiv, 6, refweight);
 
     } else if (strcasecmp(text, "ageandlength") == 0) {
